<?xml version="1.0" encoding="UTF-8"?>
<!-- FZ811_571v2.0_VALXSLTu2, 16 november 2020 -->
<xsl:stylesheet version="1.0"
xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
xmlns:fz="http://ei.vektis.nl/verantwoording/basisschema/v2_0"
xmlns:fz811="http://ei.vektis.nl/verantwoording/fz811/v2_0"
xmlns:fz812="http://ei.vektis.nl/verantwoording/fz812/v2_0">
 	 	
 	<xsl:import href="rc8028.xslt"/>
 	<xsl:import href="rc8986.xslt"/>
	<xsl:import href="rc9225.xslt"/>
 	<xsl:import href="rc9226.xslt"/>
	<xsl:import href="rc9229.xslt"/>
	<xsl:import href="rc9230.xslt"/>
	<xsl:import href="rc9231.xslt"/>
	<xsl:import href="rc9233.xslt"/>
	<xsl:import href="rc8188.xslt"/>
 	<xsl:import href="rc8646.xslt"/>
 	<xsl:import href="rc9232.xslt"/>
	
	<!-- Uitvoer is fz812_572 bericht met Retourcodes. -->
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes" />
	
	<xsl:variable name="Berichtcode" select="//fz811:Bericht/fz811:Header/fz811:Berichtcode"/> 
	<xsl:variable name="BerichtSoort" select="//fz811:Bericht/fz811:Header/fz:BerichtSoort"/> 
	<xsl:variable name="Verzenddatum" select="translate(//fz811:Bericht/fz811:Header/fz:Verzenddatum, '-', '')"/>
	<xsl:variable name="EinddatumVerantwoordingsperiode" select="translate(//fz811:Bericht/fz811:Header/fz:EinddatumVerantwoordingsperiode, '-', '')"/>

	<xsl:template match="//fz811:Bericht">
		<fz812:Bericht>
			<xsl:attribute name="xsi:schemaLocation">http://ei.vektis.nl/verantwoording/fz812/v2_0 fz812_v2_572.xsd</xsl:attribute>
			<!-- Controleer op errors in de Header -->
			<!-- retourcode 8028: Soort bericht ontbreekt of is onjuist -->
			<xsl:variable name="rc8028">
				<xsl:call-template name="rc8028">
					<xsl:with-param name="BerichtSoort" select="$BerichtSoort"/>
				</xsl:call-template>
			</xsl:variable>
				
			<!-- retourcode 8986: Verzenddatum moet kleiner zijn dan of gelijk zijn aan de huidige datum. -->
			<xsl:variable name="rc8986">
				<xsl:call-template name="rc8986">
					<xsl:with-param name="Verzenddatum" select="$Verzenddatum"/>
					<xsl:with-param name="BerichtSoort" select="$BerichtSoort"/>
				</xsl:call-template>
			</xsl:variable> 
			
			<!-- retourcode 9226: EinddatumVerantwoordingsperiode moet kleiner zijn dan of gelijk zijn aan de huidige datum. -->
			<xsl:variable name="rc9226">
				<xsl:call-template name="rc9226">
					<xsl:with-param name="EinddatumVerantwoordingsperiode" select="$EinddatumVerantwoordingsperiode"/>
					<xsl:with-param name="BerichtSoort" select="$BerichtSoort"/>
				</xsl:call-template>
			</xsl:variable> 
			
			<xsl:choose>
				<!-- Geen errors in de Header, dan hele bericht als retour -->
				<xsl:when test="$rc8028='' and $rc8986='' and $rc9226=''" >
					<xsl:apply-templates select="fz811:Header"/>
					<xsl:apply-templates select="fz811:Totaal"/>
					<xsl:apply-templates select="fz811:Plaatsingsbesluiten"/>
				</xsl:when>
				<!-- Wel errors in de Header, dan alleen Header als retour -->
				<xsl:otherwise>
					<xsl:apply-templates select="fz811:Header"/>
				</xsl:otherwise>
			</xsl:choose>
		</fz812:Bericht>
	</xsl:template>	

	<xsl:template match="fz811:Header">
		<fz812:Header>
			<fz812:Berichtcode>572</fz812:Berichtcode>
			<xsl:apply-templates select="fz:BerichtVersie" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz:BerichtSubversie" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz:BerichtSoort" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz:CodeServicebureau" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz:Instellingscode" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz:UzoviNummer" mode="copy-if-exists"/>			
			<xsl:apply-templates select="fz:AfzenderReferentienummer" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz:Verzenddatum" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz:EinddatumVerantwoordingsperiode" mode="copy-if-exists"/>
			
  	       	<fz812:Retourcodes>
				
				<!-- retourcode 8028: Soort bericht ontbreekt of is onjuist -->
				<xsl:variable name="rc8028">
					<xsl:call-template name="rc8028">
						<xsl:with-param name="BerichtSoort" select="$BerichtSoort"/>
					</xsl:call-template>
				</xsl:variable>
					
				<!-- retourcode 8920: Verzenddatum moet kleiner zijn dan of gelijk zijn aan de huidige datum. -->
				<xsl:variable name="rc8986">
					<xsl:call-template name="rc8986">
						<xsl:with-param name="Verzenddatum" select="$Verzenddatum"/>
						<xsl:with-param name="BerichtSoort" select="$BerichtSoort"/>
					</xsl:call-template>
				</xsl:variable> 

				<!-- retourcode 9226: EinddatumVerantwoordingsperiode moet kleiner zijn dan of gelijk zijn aan de huidige datum. -->
				<xsl:variable name="rc9226">
					<xsl:call-template name="rc9226">
						<xsl:with-param name="EinddatumVerantwoordingsperiode" select="$EinddatumVerantwoordingsperiode"/>
						<xsl:with-param name="BerichtSoort" select="$BerichtSoort"/>
					</xsl:call-template>
				</xsl:variable> 
					
				<xsl:copy-of select="$rc8028"/>
				<xsl:copy-of select="$rc8986"/>
				<xsl:copy-of select="$rc9226"/>
					
				<!-- Wanneer de klasse correct is dan wordt een 0200 retourcode toegevoegd. -->
				<xsl:if test="$rc8028='' and $rc8986='' and $rc9226=''">
					<fz812:Retourcode>0200</fz812:Retourcode>
				</xsl:if>
					
			</fz812:Retourcodes>
		</fz812:Header>
	</xsl:template>
		
	<xsl:template match="fz811:Totaal">	
		<fz812:Totaal>
			
			<xsl:apply-templates select="fz811:TotaalANGZZP"/>
			<xsl:apply-templates select="fz811:TotaalANGEP"/>
			<xsl:apply-templates select="fz811:TotaalANGVPT"/>

  	       	<fz812:Retourcodes>

				<xsl:variable name="TotaalbedragANGZZP" select="fz811:TotaalANGZZP/fz811:SomTotaalbedrag"/>
				<xsl:variable name="TotaalbedragANGEP" select="fz811:TotaalANGEP/fz811:SomTotaalbedrag"/>
				<xsl:variable name="TotaalbedragANGVPT" select="fz811:TotaalANGVPT/fz811:SomTotaalbedrag"/>

				<!-- retourcode 9229: SomTotaalbedrag ANGZZP komt niet overeen met totaal van plaatsingsbesluiten ANGZZP.-->
				<xsl:variable name="rc9229">
					<xsl:call-template name="rc9229">
						<xsl:with-param name="SomTotaalbedrag" select="$TotaalbedragANGZZP"/>
						<xsl:with-param name="TotaalPlaatsingsbesluiten" select="sum(//fz811:Bericht/fz811:Plaatsingsbesluiten/fz811:Plaatsingsbesluit/fz811:ANGZZP/fz:Totaalbedrag)"/>
					</xsl:call-template>
				</xsl:variable>

				<!-- retourcode 9230: SomTotaalbedrag ANGEP komt niet overeen met totaal van plaatsingsbesluiten ANGEP.-->
				<xsl:variable name="rc9230">
					<xsl:call-template name="rc9230">
						<xsl:with-param name="SomTotaalbedrag" select="$TotaalbedragANGEP"/>
						<xsl:with-param name="TotaalPlaatsingsbesluiten" select="sum(//fz811:Bericht/fz811:Plaatsingsbesluiten/fz811:Plaatsingsbesluit/fz811:ANGEP/fz:Totaalbedrag)"/>
					</xsl:call-template>
				</xsl:variable>

				<!-- retourcode 9231: SomTotaalbedrag ANGVPT komt niet overeen met totaal van plaatsingsbesluiten ANGVPT.-->
				<xsl:variable name="rc9231">
					<xsl:call-template name="rc9231">
						<xsl:with-param name="SomTotaalbedrag" select="$TotaalbedragANGVPT"/>
						<xsl:with-param name="TotaalPlaatsingsbesluiten" select="sum(//fz811:Bericht/fz811:Plaatsingsbesluiten/fz811:Plaatsingsbesluit/fz811:ANGVPT/fz:Totaalbedrag)"/>
					</xsl:call-template>
				</xsl:variable>
				
				<xsl:copy-of select="$rc9229"/>
				<xsl:copy-of select="$rc9230"/>
				<xsl:copy-of select="$rc9231"/>
					
				<!-- Wanneer de klasse correct is dan wordt een 0200 retourcode toegevoegd. -->
				<xsl:if test="$rc9229='' and $rc9230='' and $rc9231=''">
					<fz812:Retourcode>0200</fz812:Retourcode>
				</xsl:if>
					
			</fz812:Retourcodes>
				
		</fz812:Totaal>
	</xsl:template>
		
	<xsl:template match="fz811:TotaalANGZZP">	
		<fz812:TotaalANGZZP>
			<xsl:apply-templates select="fz811:SomTotaalbedrag" mode="copy-if-exists"/>
		</fz812:TotaalANGZZP>
	</xsl:template>
		
	<xsl:template match="fz811:TotaalANGEP">	
		<fz812:TotaalANGEP>
			<xsl:apply-templates select="fz811:SomTotaalbedrag" mode="copy-if-exists"/>
		</fz812:TotaalANGEP>
	</xsl:template>
		
	<xsl:template match="fz811:TotaalANGVPT">	
		<fz812:TotaalANGVPT>
			<xsl:apply-templates select="fz811:SomTotaalbedrag" mode="copy-if-exists"/>
		</fz812:TotaalANGVPT>
	</xsl:template>
		
	<xsl:template match="fz811:Plaatsingsbesluiten">
		<fz812:Plaatsingsbesluiten>
			<xsl:apply-templates select="fz811:Plaatsingsbesluit"/>
		</fz812:Plaatsingsbesluiten>
	</xsl:template>

	<xsl:template match="fz811:Plaatsingsbesluit">
		<fz812:Plaatsingsbesluit>
			<xsl:apply-templates select="fz:Zorgcontractnummer" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz:Plaatsingsbesluitnummer" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz:Verzekerdennummer" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz:BegindatumPrestatie" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz811:EinddatumPrestatie" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz811:ANGZZP"/>
			<xsl:apply-templates select="fz811:ANGEP"/>
			<xsl:apply-templates select="fz811:ANGVPT"/>
				
			<fz812:Retourcodes>
			
				<!-- retourcode 9225: BegindatumPrestatie moet kleiner zijn dan of gelijk zijn aan de EinddatumVerantwoordingsperiode. -->
				<xsl:variable name="rc9225">
					<xsl:call-template name="rc9225">
						<xsl:with-param name="EinddatumVerantwoordingsperiode" select="$EinddatumVerantwoordingsperiode"/>
						<xsl:with-param name="BegindatumPrestatie" select="translate(fz:BegindatumPrestatie, '-', '')"/>
					</xsl:call-template>
				</xsl:variable>
						
				<!-- retourcode 9233: EinddatumPrestatie moet kleiner zijn dan of gelijk zijn aan de EinddatumVerantwoordingsperiode. -->
				<xsl:variable name="rc9233">
					<xsl:call-template name="rc9233">
						<xsl:with-param name="EinddatumVerantwoordingsperiode" select="$EinddatumVerantwoordingsperiode"/>
						<xsl:with-param name="EinddatumPrestatie" select="translate(fz811:EinddatumPrestatie, '-', '')"/>
					</xsl:call-template>
				</xsl:variable>
						
				<!-- retourcode 8188: BegindatumPrestatie moet kleiner zijn dan of gelijk zijn aan de EinddatumPrestatie. -->
				<xsl:variable name="rc8188">
					<xsl:call-template name="rc8188">
						<xsl:with-param name="BegindatumPrestatie" select="translate(fz:BegindatumPrestatie, '-', '')"/>
						<xsl:with-param name="EinddatumPrestatie" select="translate(fz811:EinddatumPrestatie, '-', '')"/>
					</xsl:call-template>
				</xsl:variable>
						
				<!-- retourcode 8646: BegindatumPrestatie en EinddatumPrestatie moeten in dezelfde maand liggen. -->
				<xsl:variable name="rc8646">
					<xsl:call-template name="rc8646">
						<xsl:with-param name="BegindatumPrestatie" select="translate(fz:BegindatumPrestatie, '-', '')"/>
						<xsl:with-param name="EinddatumPrestatie" select="translate(fz811:EinddatumPrestatie, '-', '')"/>
					</xsl:call-template>
				</xsl:variable>

				<xsl:copy-of select="$rc9225"/>
				<xsl:copy-of select="$rc9233"/>
				<xsl:copy-of select="$rc8188"/>
				<xsl:copy-of select="$rc8646"/>
				
				<xsl:if test="fz811:ANGZZP">	
					<!-- retourcode 9232: Controle of aantal tijdseenheden overeenstemmen met BegindatumPrestatie en EinddatumPrestatie.
					 Let op: het aantal tijdseenheden kan negatief zijn bij een credit, in dat geval ABS(aantal tijdseenheden) beschouwen-->
					<xsl:variable name="AantalPrestaties">
					<xsl:choose>
						<xsl:when test="fz811:ANGZZP/fz:AantalUitgevoerdePrestaties &lt; 0">
							<xsl:value-of select="fz811:ANGZZP/fz:AantalUitgevoerdePrestaties * (-1)"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="fz811:ANGZZP/fz:AantalUitgevoerdePrestaties"/>
						</xsl:otherwise>
					</xsl:choose>
					</xsl:variable>	
				
					<xsl:variable name="rc9232">
						<xsl:call-template name="rc9232">
							<xsl:with-param name="TijdseenheidZorgperiode" select="fz811:ANGZZP/fz:TijdseenheidZorgperiode"/>
							<xsl:with-param name="Aantaldagen" select="$AantalPrestaties"/>
							<xsl:with-param name="BegindatumPrestatie" select="translate(fz:BegindatumPrestatie, '-', '')"/>
							<xsl:with-param name="EinddatumPrestatie" select="translate(fz811:EinddatumPrestatie, '-', '')"/>
						</xsl:call-template>
					</xsl:variable>

					<xsl:copy-of select="$rc9232"/>
					
					<!-- Wanneer de klasse correct is dan wordt een 0200 retourcode toegevoegd. -->
					<xsl:if test="$rc9225='' and $rc9233='' and $rc8188='' and $rc8646='' and $rc9232=''">
						<fz812:Retourcode>0200</fz812:Retourcode>
					</xsl:if>					
				</xsl:if>					
						
				<xsl:if test="fz811:ANGEP">	
					<!-- retourcode 9232: Controle of aantal tijdseenheden overeenstemmen met BegindatumPrestatie en EinddatumPrestatie.
					 Let op: het aantal tijdseenheden kan negatief zijn bij een credit, in dat geval ABS(aantal tijdseenheden) beschouwen-->
					<xsl:variable name="AantalPrestaties">
					<xsl:choose>
						<xsl:when test="fz811:ANGEP/fz:AantalUitgevoerdePrestaties &lt; 0">
							<xsl:value-of select="fz811:ANGEP/fz:AantalUitgevoerdePrestaties * (-1)"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="fz811:ANGEP/fz:AantalUitgevoerdePrestaties"/>
						</xsl:otherwise>
					</xsl:choose>
					</xsl:variable>	
				
					<xsl:variable name="rc9232">
						<xsl:call-template name="rc9232">
							<xsl:with-param name="TijdseenheidZorgperiode" select="fz811:ANGEP/fz:TijdseenheidZorgperiode"/>
							<xsl:with-param name="Aantaldagen" select="$AantalPrestaties"/>
							<xsl:with-param name="BegindatumPrestatie" select="translate(fz:BegindatumPrestatie, '-', '')"/>
							<xsl:with-param name="EinddatumPrestatie" select="translate(fz811:EinddatumPrestatie, '-', '')"/>
						</xsl:call-template>
					</xsl:variable>

					<xsl:copy-of select="$rc9232"/>
					
					<!-- Wanneer de klasse correct is dan wordt een 0200 retourcode toegevoegd. -->
					<xsl:if test="$rc9225='' and $rc9233='' and $rc8188='' and $rc8646='' and $rc9232=''">
						<fz812:Retourcode>0200</fz812:Retourcode>
					</xsl:if>					
				</xsl:if>					
						
				<xsl:if test="fz811:ANGVPT">	
					<!-- retourcode 9232: Controle of aantal tijdseenheden overeenstemmen met BegindatumPrestatie en EinddatumPrestatie.
					 Let op: het aantal tijdseenheden kan negatief zijn bij een credit, in dat geval ABS(aantal tijdseenheden) beschouwen-->
					<xsl:variable name="AantalPrestaties">
					<xsl:choose>
						<xsl:when test="fz811:ANGVPT/fz:AantalUitgevoerdePrestaties &lt; 0">
							<xsl:value-of select="fz811:ANGVPT/fz:AantalUitgevoerdePrestaties * (-1)"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="fz811:ANGVPT/fz:AantalUitgevoerdePrestaties"/>
						</xsl:otherwise>
					</xsl:choose>
					</xsl:variable>	
				
					<xsl:variable name="rc9232">
						<xsl:call-template name="rc9232">
							<xsl:with-param name="TijdseenheidZorgperiode" select="fz811:ANGVPT/fz:TijdseenheidZorgperiode"/>
							<xsl:with-param name="Aantaldagen" select="$AantalPrestaties"/>
							<xsl:with-param name="BegindatumPrestatie" select="translate(fz:BegindatumPrestatie, '-', '')"/>
							<xsl:with-param name="EinddatumPrestatie" select="translate(fz811:EinddatumPrestatie, '-', '')"/>
						</xsl:call-template>
					</xsl:variable>

					<xsl:copy-of select="$rc9232"/>
					
					<!-- Wanneer de klasse correct is dan wordt een 0200 retourcode toegevoegd. -->
					<xsl:if test="$rc9225='' and $rc9233='' and $rc8188='' and $rc8646='' and $rc9232=''">
						<fz812:Retourcode>0200</fz812:Retourcode>
					</xsl:if>					
				</xsl:if>					
						
			</fz812:Retourcodes>			
			
		</fz812:Plaatsingsbesluit>
	</xsl:template>
	
	<xsl:template match="fz811:ANGZZP">
		<fz812:ANGZZP>
			<xsl:apply-templates select="fz:AanduidingPrestatiecodelijst" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz:Prestatiecode" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz:AantalUitgevoerdePrestaties" mode="copy-if-exists"/>		
			<xsl:apply-templates select="fz:TijdseenheidZorgperiode" mode="copy-if-exists"/>		
			<xsl:apply-templates select="fz:Totaalbedrag" mode="copy-if-exists"/>
		</fz812:ANGZZP>
	</xsl:template>

	<xsl:template match="fz811:ANGEP">
		<fz812:ANGEP>
			<xsl:apply-templates select="fz:AanduidingPrestatiecodelijst" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz:Prestatiecode" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz:AantalUitgevoerdePrestaties" mode="copy-if-exists"/>		
			<xsl:apply-templates select="fz:TijdseenheidZorgperiode" mode="copy-if-exists"/>		
			<xsl:apply-templates select="fz:Totaalbedrag" mode="copy-if-exists"/>
		</fz812:ANGEP>
	</xsl:template>

	<xsl:template match="fz811:ANGVPT">
		<fz812:ANGVPT>
			<xsl:apply-templates select="fz:AanduidingPrestatiecodelijst" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz:Prestatiecode" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz:AantalUitgevoerdePrestaties" mode="copy-if-exists"/>		
			<xsl:apply-templates select="fz:TijdseenheidZorgperiode" mode="copy-if-exists"/>		
			<xsl:apply-templates select="fz:Totaalbedrag" mode="copy-if-exists"/>
		</fz812:ANGVPT>
	</xsl:template>		
		
	<!-- Copy template: als een enkel element voorkomt is, wordt deze gekopieerd in de opgegeven namespace -->
	<xsl:template match="fz811:*" mode="copy-if-exists">
		<xsl:param name="NameSpacePrefix" select="'fz812:'"/>
		<xsl:if test=".">
			<xsl:element name="{concat($NameSpacePrefix,local-name())}">
				<xsl:value-of select="text()"/>
			</xsl:element>
		</xsl:if>
            
	</xsl:template>
	<xsl:template match="*[not(starts-with(name(), 'fz811:'))]" mode="copy-if-exists">
        <xsl:if test=".">
            <xsl:element name="{name()}">
				<xsl:value-of select="text()"/>
            </xsl:element>
        </xsl:if>
	</xsl:template>
	
</xsl:stylesheet>